@@ -52,6 +52,10 @@ class ChecksTests(SimpleTestCase):
     def test_cors_allow_credentials_non_bool(self):
         self.check_error_codes(["corsheaders.E003"])
 
+    @override_settings(CORS_ALLOW_PRIVATE_NETWORK=object)
+    def test_cors_allow_network_access_non_bool(self):
+        self.check_error_codes(["corsheaders.E015"])
+
     @override_settings(CORS_PREFLIGHT_MAX_AGE="10")
     def test_cors_preflight_max_age_non_integer(self):
         self.check_error_codes(["corsheaders.E004"])
@@ -83,7 +87,7 @@ class ChecksTests(SimpleTestCase):
         errors = self.check_error_codes(["corsheaders.E006"])
         assert errors[0].msg.startswith("CORS_ORIGIN_WHITELIST should be")
 
-    @override_settings(CORS_ALLOWED_ORIGINS=["http://example.com", "file://", "null"])
+    @override_settings(CORS_ALLOWED_ORIGINS=["https://example.com", "file://", "null"])
     def test_cors_allowed_origins_allowed(self):
         self.check_error_codes([])
 
@@ -136,10 +140,10 @@ class ChecksTests(SimpleTestCase):
     def test_cors_urls_regex_non_string(self):
         self.check_error_codes(["corsheaders.E009"])
 
-    @override_settings(CORS_REPLACE_HTTPS_REFERER=object)
-    def test_cors_replace_https_referer_failure(self):
-        self.check_error_codes(["corsheaders.E011"])
-
     @override_settings(CORS_MODEL="something")
     def test_cors_model_failure(self):
         self.check_error_codes(["corsheaders.E012"])
+
+    @override_settings(CORS_REPLACE_HTTPS_REFERER="something")
+    def test_cors_replace_https_referer_failure(self):
+        self.check_error_codes(["corsheaders.E013"])
