@@ -33,24 +33,24 @@ class CorsMiddlewareTests(TestCase):
         assert resp["vary"] == "origin"
 
     def test_get_invalid_origin(self):
-        resp = self.client.get("/", HTTP_ORIGIN="https://example.com]")
+        resp = self.client.get("/", headers={"origin": "https://example.com]"})
         assert ACCESS_CONTROL_ALLOW_ORIGIN not in resp
 
     @override_settings(CORS_ALLOWED_ORIGINS=["https://example.com"])
     def test_get_not_in_allowed_origins(self):
-        resp = self.client.get("/", HTTP_ORIGIN="https://example.org")
+        resp = self.client.get("/", headers={"origin": "https://example.org"})
         assert ACCESS_CONTROL_ALLOW_ORIGIN not in resp
 
     @override_settings(CORS_ALLOWED_ORIGINS=["http://example.org"])
     def test_get_not_in_allowed_origins_due_to_wrong_scheme(self):
-        resp = self.client.get("/", HTTP_ORIGIN="https://example.org")
+        resp = self.client.get("/", headers={"origin": "https://example.org"})
         assert ACCESS_CONTROL_ALLOW_ORIGIN not in resp
 
     @override_settings(
         CORS_ALLOWED_ORIGINS=["https://example.com", "https://example.org"]
     )
     def test_get_in_allowed_origins(self):
-        resp = self.client.get("/", HTTP_ORIGIN="https://example.org")
+        resp = self.client.get("/", headers={"origin": "https://example.org"})
         assert resp[ACCESS_CONTROL_ALLOW_ORIGIN] == "https://example.org"
 
     @override_settings(CORS_ALLOWED_ORIGINS=["https://example.org"])
@@ -60,7 +60,7 @@ class CorsMiddlewareTests(TestCase):
 
     @override_settings(CORS_ALLOWED_ORIGINS=["https://example.com", "null"])
     def test_null_in_allowed_origins(self):
-        resp = self.client.get("/", HTTP_ORIGIN="null")
+        resp = self.client.get("/", headers={"origin": "null"})
         assert resp[ACCESS_CONTROL_ALLOW_ORIGIN] == "null"
 
     @override_settings(CORS_ALLOWED_ORIGINS=["https://example.com", "file://"])
@@ -69,7 +69,7 @@ class CorsMiddlewareTests(TestCase):
         'file://' should be allowed as an origin since Chrome on Android
         mistakenly sends it
         """
-        resp = self.client.get("/", HTTP_ORIGIN="file://")
+        resp = self.client.get("/", headers={"origin": "file://"})
         assert resp[ACCESS_CONTROL_ALLOW_ORIGIN] == "file://"
 
     @override_settings(
@@ -77,45 +77,47 @@ class CorsMiddlewareTests(TestCase):
         CORS_EXPOSE_HEADERS=["accept", "content-type"],
     )
     def test_get_expose_headers(self):
-        resp = self.client.get("/", HTTP_ORIGIN="https://example.com")
+        resp = self.client.get("/", headers={"origin": "https://example.com"})
         assert resp[ACCESS_CONTROL_EXPOSE_HEADERS] == "accept, content-type"
 
     @override_settings(CORS_ALLOW_ALL_ORIGINS=True)
     def test_get_dont_expose_headers(self):
-        resp = self.client.get("/", HTTP_ORIGIN="https://example.com")
+        resp = self.client.get("/", headers={"origin": "https://example.com"})
         assert ACCESS_CONTROL_EXPOSE_HEADERS not in resp
 
     @override_settings(
         CORS_ALLOWED_ORIGINS=["https://example.com"], CORS_ALLOW_CREDENTIALS=True
     )
     def test_get_allow_credentials(self):
-        resp = self.client.get("/", HTTP_ORIGIN="https://example.com")
+        resp = self.client.get("/", headers={"origin": "https://example.com"})
         assert resp[ACCESS_CONTROL_ALLOW_CREDENTIALS] == "true"
 
     @override_settings(
         CORS_ALLOWED_ORIGINS=["https://example.com"], CORS_ALLOW_CREDENTIALS=True
     )
     def test_get_allow_credentials_bad_origin(self):
-        resp = self.client.get("/", HTTP_ORIGIN="https://example.org")
+        resp = self.client.get("/", headers={"origin": "https://example.org"})
         assert ACCESS_CONTROL_ALLOW_CREDENTIALS not in resp
 
     @override_settings(CORS_ALLOWED_ORIGINS=["https://example.com"])
     def test_get_allow_credentials_disabled(self):
-        resp = self.client.get("/", HTTP_ORIGIN="https://example.com")
+        resp = self.client.get("/", headers={"origin": "https://example.com"})
         assert ACCESS_CONTROL_ALLOW_CREDENTIALS not in resp
 
     @override_settings(CORS_ALLOW_PRIVATE_NETWORK=True, CORS_ALLOW_ALL_ORIGINS=True)
     def test_allow_private_network_added_if_enabled_and_requested(self):
         resp = self.client.get(
             "/",
-            HTTP_ACCESS_CONTROL_REQUEST_PRIVATE_NETWORK="true",
-            HTTP_ORIGIN="http://example.com",
+            headers={
+                "access-control-request-private-network": "true",
+                "origin": "http://example.com",
+            },
         )
         assert resp[ACCESS_CONTROL_ALLOW_PRIVATE_NETWORK] == "true"
 
     @override_settings(CORS_ALLOW_PRIVATE_NETWORK=True, CORS_ALLOW_ALL_ORIGINS=True)
     def test_allow_private_network_not_added_if_enabled_and_not_requested(self):
-        resp = self.client.get("/", HTTP_ORIGIN="http://example.com")
+        resp = self.client.get("/", headers={"origin": "http://example.com"})
         assert ACCESS_CONTROL_ALLOW_PRIVATE_NETWORK not in resp
 
     @override_settings(
@@ -125,8 +127,10 @@ class CorsMiddlewareTests(TestCase):
     def test_allow_private_network_not_added_if_enabled_and_no_cors_origin(self):
         resp = self.client.get(
             "/",
-            HTTP_ACCESS_CONTROL_REQUEST_PRIVATE_NETWORK="true",
-            HTTP_ORIGIN="http://example.org",
+            headers={
+                "access-control-request-private-network": "true",
+                "origin": "http://example.org",
+            },
         )
         assert ACCESS_CONTROL_ALLOW_PRIVATE_NETWORK not in resp
 
@@ -134,8 +138,10 @@ class CorsMiddlewareTests(TestCase):
     def test_allow_private_network_not_added_if_disabled_and_requested(self):
         resp = self.client.get(
             "/",
-            HTTP_ACCESS_CONTROL_REQUEST_PRIVATE_NETWORK="true",
-            HTTP_ORIGIN="http://example.com",
+            headers={
+                "access-control-request-private-network": "true",
+                "origin": "http://example.com",
+            },
         )
         assert ACCESS_CONTROL_ALLOW_PRIVATE_NETWORK not in resp
 
@@ -148,8 +154,10 @@ class CorsMiddlewareTests(TestCase):
     def test_options_allowed_origin(self):
         resp = self.client.options(
             "/",
-            HTTP_ORIGIN="https://example.com",
-            HTTP_ACCESS_CONTROL_REQUEST_METHOD="GET",
+            headers={
+                "origin": "https://example.com",
+                "access-control-request-method": "GET",
+            },
         )
         assert resp.status_code == HTTPStatus.OK
         assert resp[ACCESS_CONTROL_ALLOW_HEADERS] == "content-type"
@@ -182,8 +190,10 @@ class CorsMiddlewareTests(TestCase):
     def test_options_no_max_age(self):
         resp = self.client.options(
             "/",
-            HTTP_ORIGIN="https://example.com",
-            HTTP_ACCESS_CONTROL_REQUEST_METHOD="GET",
+            headers={
+                "origin": "https://example.com",
+                "access-control-request-method": "GET",
+            },
         )
         assert resp[ACCESS_CONTROL_ALLOW_HEADERS] == "content-type"
         assert resp[ACCESS_CONTROL_ALLOW_METHODS] == "GET, OPTIONS"
@@ -195,8 +205,10 @@ class CorsMiddlewareTests(TestCase):
     def test_options_allowed_origins_with_port(self):
         resp = self.client.options(
             "/",
-            HTTP_ORIGIN="https://localhost:9000",
-            HTTP_ACCESS_CONTROL_REQUEST_METHOD="GET",
+            headers={
+                "origin": "https://localhost:9000",
+                "access-control-request-method": "GET",
+            },
         )
         assert resp[ACCESS_CONTROL_ALLOW_ORIGIN] == "https://localhost:9000"
 
@@ -206,8 +218,10 @@ class CorsMiddlewareTests(TestCase):
     def test_options_adds_origin_when_domain_found_in_allowed_regexes(self):
         resp = self.client.options(
             "/",
-            HTTP_ORIGIN="https://foo.example.com",
-            HTTP_ACCESS_CONTROL_REQUEST_METHOD="GET",
+            headers={
+                "origin": "https://foo.example.com",
+                "access-control-request-method": "GET",
+            },
         )
         assert resp[ACCESS_CONTROL_ALLOW_ORIGIN] == "https://foo.example.com"
 
@@ -220,8 +234,10 @@ class CorsMiddlewareTests(TestCase):
     def test_options_adds_origin_when_domain_found_in_allowed_regexes_second(self):
         resp = self.client.options(
             "/",
-            HTTP_ORIGIN="https://foo.example.com",
-            HTTP_ACCESS_CONTROL_REQUEST_METHOD="GET",
+            headers={
+                "origin": "https://foo.example.com",
+                "access-control-request-method": "GET",
+            },
         )
         assert resp[ACCESS_CONTROL_ALLOW_ORIGIN] == "https://foo.example.com"
 
@@ -233,16 +249,20 @@ class CorsMiddlewareTests(TestCase):
     ):
         resp = self.client.options(
             "/",
-            HTTP_ORIGIN="https://foo.example.com",
-            HTTP_ACCESS_CONTROL_REQUEST_METHOD="GET",
+            headers={
+                "origin": "https://foo.example.com",
+                "access-control-request-method": "GET",
+            },
         )
         assert ACCESS_CONTROL_ALLOW_ORIGIN not in resp
 
     def test_options_empty_request_method(self):
         resp = self.client.options(
             "/",
-            HTTP_ORIGIN="https://example.com",
-            HTTP_ACCESS_CONTROL_REQUEST_METHOD="",
+            headers={
+                "origin": "https://example.com",
+                "access-control-request-method": "",
+            },
         )
         assert resp.status_code == HTTPStatus.OK
 
@@ -254,8 +274,10 @@ class CorsMiddlewareTests(TestCase):
     def test_allow_all_origins_get(self):
         resp = self.client.get(
             "/",
-            HTTP_ORIGIN="https://example.com",
-            HTTP_ACCESS_CONTROL_REQUEST_METHOD="GET",
+            headers={
+                "origin": "https://example.com",
+                "access-control-request-method": "GET",
+            },
         )
         assert resp.status_code == HTTPStatus.OK
         assert resp[ACCESS_CONTROL_ALLOW_ORIGIN] == "https://example.com"
@@ -265,8 +287,10 @@ class CorsMiddlewareTests(TestCase):
     def test_allow_all_origins_options(self):
         resp = self.client.options(
             "/",
-            HTTP_ORIGIN="https://example.com",
-            HTTP_ACCESS_CONTROL_REQUEST_METHOD="GET",
+            headers={
+                "origin": "https://example.com",
+                "access-control-request-method": "GET",
+            },
         )
         assert resp.status_code == HTTPStatus.OK
         assert resp[ACCESS_CONTROL_ALLOW_ORIGIN] == "https://example.com"
@@ -282,7 +306,9 @@ class CorsMiddlewareTests(TestCase):
         place to preserve this behaviour. See `ExceptionMiddleware` mention here:
         https://docs.djangoproject.com/en/3.0/topics/http/middleware/#upgrading-pre-django-1-10-style-middleware  # noqa: E501
         """
-        resp = self.client.get("/unauthorized/", HTTP_ORIGIN="https://example.com")
+        resp = self.client.get(
+            "/unauthorized/", headers={"origin": "https://example.com"}
+        )
         assert resp.status_code == HTTPStatus.UNAUTHORIZED
         assert resp[ACCESS_CONTROL_ALLOW_ORIGIN] == "https://example.com"
 
@@ -294,8 +320,10 @@ class CorsMiddlewareTests(TestCase):
         """
         resp = self.client.options(
             "/test-401/",
-            HTTP_ORIGIN="https://example.com",
-            HTTP_ACCESS_CONTROL_REQUEST_METHOD="GET",
+            headers={
+                "origin": "https://example.com",
+                "access-control-request-method": "GET",
+            },
         )
         assert resp.status_code == HTTPStatus.OK
         assert resp[ACCESS_CONTROL_ALLOW_ORIGIN] == "https://example.com"
@@ -308,8 +336,10 @@ class CorsMiddlewareTests(TestCase):
         with temporary_check_request_hander(handler):
             resp = self.client.options(
                 "/",
-                HTTP_ORIGIN="https://example.com",
-                HTTP_ACCESS_CONTROL_REQUEST_METHOD="GET",
+                headers={
+                    "origin": "https://example.com",
+                    "access-control-request-method": "GET",
+                },
             )
 
             assert resp.status_code == HTTPStatus.OK
@@ -322,8 +352,10 @@ class CorsMiddlewareTests(TestCase):
         with temporary_check_request_hander(handler):
             resp = self.client.options(
                 "/",
-                HTTP_ORIGIN="https://example.com",
-                HTTP_ACCESS_CONTROL_REQUEST_METHOD="GET",
+                headers={
+                    "origin": "https://example.com",
+                    "access-control-request-method": "GET",
+                },
             )
             assert resp.status_code == HTTPStatus.OK
             assert resp[ACCESS_CONTROL_ALLOW_ORIGIN] == "https://example.com"
@@ -336,16 +368,20 @@ class CorsMiddlewareTests(TestCase):
         with temporary_check_request_hander(allow_api_to_all):
             resp = self.client.options(
                 "/",
-                HTTP_ORIGIN="https://example.org",
-                HTTP_ACCESS_CONTROL_REQUEST_METHOD="GET",
+                headers={
+                    "origin": "https://example.org",
+                    "access-control-request-method": "GET",
+                },
             )
             assert resp.status_code == HTTPStatus.OK
             assert ACCESS_CONTROL_ALLOW_ORIGIN not in resp
 
             resp = self.client.options(
                 "/api/something/",
-                HTTP_ORIGIN="https://example.org",
-                HTTP_ACCESS_CONTROL_REQUEST_METHOD="GET",
+                headers={
+                    "origin": "https://example.org",
+                    "access-control-request-method": "GET",
+                },
             )
             assert resp.status_code == HTTPStatus.OK
             assert resp[ACCESS_CONTROL_ALLOW_ORIGIN] == "https://example.org"
@@ -360,7 +396,7 @@ class CorsMiddlewareTests(TestCase):
             return True
 
         with temporary_check_request_hander(allow_all):
-            self.client.get("/", HTTP_ORIGIN="https://example.org")
+            self.client.get("/", headers={"origin": "https://example.org"})
 
             assert calls == 1
 
@@ -373,7 +409,7 @@ class CorsMiddlewareTests(TestCase):
         ``CorsMiddleware.process_response()`` should ignore the request if
         MIDDLEWARE setting is used (new mechanism in Django 1.10+).
         """
-        resp = self.client.get("/", HTTP_ORIGIN="https://example.com")
+        resp = self.client.get("/", headers={"origin": "https://example.com"})
         assert ACCESS_CONTROL_ALLOW_ORIGIN not in resp
 
     @override_settings(
@@ -381,21 +417,21 @@ class CorsMiddlewareTests(TestCase):
     )
     @prepend_middleware(f"{__name__}.ShortCircuitMiddleware")
     def test_get_short_circuit_should_be_ignored(self):
-        resp = self.client.get("/", HTTP_ORIGIN="https://example.com")
+        resp = self.client.get("/", headers={"origin": "https://example.com"})
         assert ACCESS_CONTROL_ALLOW_ORIGIN not in resp
 
     @override_settings(
         CORS_ALLOWED_ORIGINS=["https://example.com"], CORS_URLS_REGEX=r"^/foo/$"
     )
     def test_get_regex_matches(self):
-        resp = self.client.get("/foo/", HTTP_ORIGIN="https://example.com")
+        resp = self.client.get("/foo/", headers={"origin": "https://example.com"})
         assert ACCESS_CONTROL_ALLOW_ORIGIN in resp
 
     @override_settings(
         CORS_ALLOWED_ORIGINS=["https://example.com"], CORS_URLS_REGEX=r"^/not-foo/$"
     )
     def test_get_regex_doesnt_match(self):
-        resp = self.client.get("/foo/", HTTP_ORIGIN="https://example.com")
+        resp = self.client.get("/foo/", headers={"origin": "https://example.com"})
         assert ACCESS_CONTROL_ALLOW_ORIGIN not in resp
 
     @override_settings(
@@ -403,7 +439,7 @@ class CorsMiddlewareTests(TestCase):
     )
     def test_get_regex_matches_path_info(self):
         resp = self.client.get(
-            "/foo/", HTTP_ORIGIN="https://example.com", SCRIPT_NAME="/prefix/"
+            "/foo/", headers={"origin": "https://example.com"}, SCRIPT_NAME="/prefix/"
         )
         assert ACCESS_CONTROL_ALLOW_ORIGIN in resp
 
@@ -413,7 +449,7 @@ class CorsMiddlewareTests(TestCase):
         Ensure that request._cors_enabled is available - although a private API
         someone might use it for debugging
         """
-        resp = self.client.get("/", HTTP_ORIGIN="https://example.com")
+        resp = self.client.get("/", headers={"origin": "https://example.com"})
         request = resp.wsgi_request
         assert isinstance(request._cors_enabled, bool)  # type: ignore [attr-defined]
         assert request._cors_enabled  # type: ignore [attr-defined]
@@ -424,5 +460,7 @@ class CorsMiddlewareTests(TestCase):
         Just in case something crazy happens in the view or other middleware,
         check that get_response doesn't fall over if `_cors_enabled` is removed
         """
-        resp = self.client.get("/delete-enabled/", HTTP_ORIGIN="https://example.com")
+        resp = self.client.get(
+            "/delete-enabled/", headers={"origin": "https://example.com"}
+        )
         assert ACCESS_CONTROL_ALLOW_ORIGIN in resp
