@@ -1,8 +1,8 @@
 from __future__ import annotations
 
+from collections.abc import Generator
 from contextlib import contextmanager
 from typing import Callable
-from typing import Generator
 
 from django.test.utils import modify_settings
 
@@ -18,9 +18,7 @@ def prepend_middleware(path: str) -> modify_settings:
 
 
 @contextmanager
-def temporary_check_request_hander(
-    handler: Callable[..., bool]
-) -> Generator[None, None, None]:
+def temporary_check_request_hander(handler: Callable[..., bool]) -> Generator[None]:
     check_request_enabled.connect(handler)
     try:
         yield
